@@ -1,5 +1,4 @@
 import json
-import logging
 import shutil
 import typing
 from pathlib import Path
@@ -104,7 +103,7 @@ def add_custom_files(editor: PatcherEditor):
         editor.add_new_asset(str(relative), child.read_bytes(), [])
 
 
-def patch(input_path: Path, output_path: Path, configuration: dict):
+def patch_extracted(input_path: Path, output_path: Path, configuration: dict):
     LOG.info("Will patch files from %s", input_path)
 
     DefaultValidatingDraft7Validator(_read_schema()).validate(configuration)
@@ -179,49 +178,3 @@ def patch(input_path: Path, output_path: Path, configuration: dict):
     LOG.info("Done")
 
 
-def patch_with_status_update(input_path: Path, output_path: Path, configuration: dict,
-                             status_update: typing.Callable[[float, str], None]):
-    total_logs = 108
-
-    class StatusUpdateHandler(logging.Handler):
-        count = 0
-
-        def emit(self, record: logging.LogRecord) -> None:
-            message = self.format(record)
-
-            # Ignore "Writing <...>.pkg" messages, since there's also Updating...
-            if message.startswith("Writing ") and message.endswith(".pkg"):
-                return
-
-            # Encoding a bmsad is quick, skip these
-            if message.endswith(".bmsad"):
-                return
-
-            # These can come up frequently and are benign
-            if message.startswith("Skipping extracted file"):
-                return
-
-            self.count += 1
-            status_update(self.count / total_logs, message)
-
-    new_handler = StatusUpdateHandler()
-    # new_handler.setFormatter(logging.Formatter('[%(asctime)s] [%(levelname)s] %(message)s'))
-    tree_editor_log = logging.getLogger("mercury_engine_data_structures.file_tree_editor")
-
-    try:
-        tree_editor_log.setLevel(logging.DEBUG)
-        tree_editor_log.handlers.insert(0, new_handler)
-        tree_editor_log.propagate = False
-        LOG.setLevel(logging.INFO)
-        LOG.handlers.insert(0, new_handler)
-        LOG.propagate = False
-
-        patch(input_path, output_path, configuration)
-        if new_handler.count < total_logs:
-            status_update(1, f"Done was {new_handler.count}")
-
-    finally:
-        tree_editor_log.removeHandler(new_handler)
-        tree_editor_log.propagate = True
-        LOG.removeHandler(new_handler)
-        LOG.propagate = True
